@@ -18,13 +18,13 @@
  * Authors: Carlos Garnacho Parro  <carlosg@gnome.org>
  */
 
+#include <glib/gi18n.h>
+
 #include "network-iface-isdn.h"
 #include "gst.h"
 
 struct _GstIfaceIsdnPriv
 {
-  GdkPixbuf *pixbuf;
-
   gchar *login;
   gchar *password;
   gchar *phone_number;
@@ -32,6 +32,7 @@ struct _GstIfaceIsdnPriv
   gchar *section;
   
   gboolean default_gw;
+  gboolean peerdns;
   gboolean persist;
   gboolean noauth;
 };
@@ -40,12 +41,12 @@ static void gst_iface_isdn_class_init (GstIfaceIsdnClass *class);
 static void gst_iface_isdn_init       (GstIfaceIsdn      *iface);
 static void gst_iface_isdn_finalize   (GObject           *object);
 
-static const GdkPixbuf* gst_iface_isdn_get_pixbuf     (GstIface *iface);
-static const gchar*     gst_iface_isdn_get_iface_type (GstIface *iface);
-static const gchar*     gst_iface_isdn_get_desc       (GstIface *iface);
-static gboolean         gst_iface_isdn_has_gateway    (GstIface *iface);
-static void             gst_iface_isdn_impl_get_xml   (GstIface *iface,
-                                                       xmlNodePtr node);
+static GdkPixbuf*   gst_iface_isdn_get_pixbuf     (GstIface *iface);
+static const gchar* gst_iface_isdn_get_iface_type (GstIface *iface);
+static const gchar* gst_iface_isdn_get_desc       (GstIface *iface);
+static gboolean     gst_iface_isdn_has_gateway    (GstIface *iface);
+static void         gst_iface_isdn_impl_get_xml   (GstIface *iface,
+                                                   xmlNodePtr node);
 
 static void gst_iface_isdn_set_property (GObject      *object,
                                          guint         prop_id,
@@ -63,6 +64,7 @@ enum {
   PROP_PHONE_NUMBER,
   PROP_DIAL_PREFIX,
   PROP_DEFAULT_GW,
+  PROP_PEERDNS,
   PROP_PERSIST,
   PROP_SECTION,
   PROP_NOAUTH
@@ -155,7 +157,14 @@ gst_iface_isdn_class_init (GstIfaceIsdnClass *class)
                                    g_param_spec_boolean ("iface_default_gw",
                                                          "Iface default gw",
                                                          "Whether to use the iface as the default gateway",
-                                                         FALSE,
+                                                         TRUE,
+                                                         G_PARAM_READWRITE));
+  g_object_class_install_property (object_class,
+                                   PROP_PEERDNS,
+                                   g_param_spec_boolean ("iface_peerdns",
+                                                         "Iface use peer DNS",
+                                                         "Whether to use the ISP DNS",
+                                                         TRUE,
                                                          G_PARAM_READWRITE));
   g_object_class_install_property (object_class,
                                    PROP_PERSIST,
@@ -179,13 +188,18 @@ gst_iface_isdn_init (GstIfaceIsdn *iface)
   g_return_if_fail (GST_IS_IFACE_ISDN (iface));
 
   iface->_priv = g_new0 (GstIfaceIsdnPriv, 1);
-  iface->_priv->pixbuf = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/ppp.png", NULL);
 
   iface->_priv->login = NULL;
   iface->_priv->password = NULL;
   iface->_priv->phone_number = NULL;
   iface->_priv->dial_prefix = NULL;
   iface->_priv->section = NULL;
+
+  iface->_priv->default_gw = TRUE;
+  iface->_priv->peerdns = TRUE;
+
+  /* FIXME: Set here the default until we add gui for this */
+  iface->_priv->noauth = TRUE;
 }
 
 static void
@@ -197,7 +211,6 @@ gst_iface_isdn_finalize (GObject *object)
 
   if (iface->_priv)
     {
-      gdk_pixbuf_unref (iface->_priv->pixbuf);
       g_free (iface->_priv->login);
       g_free (iface->_priv->password);
       g_free (iface->_priv->phone_number);
@@ -245,6 +258,9 @@ gst_iface_isdn_set_property (GObject      *object,
     case PROP_DEFAULT_GW:
       iface->_priv->default_gw = g_value_get_boolean (value);
       break;
+    case PROP_PEERDNS:
+      iface->_priv->peerdns = g_value_get_boolean (value);
+      break;
     case PROP_PERSIST:
       iface->_priv->persist = g_value_get_boolean (value);
       break;
@@ -284,6 +300,9 @@ gst_iface_isdn_get_property (GObject      *object,
     case PROP_DEFAULT_GW:
       g_value_set_boolean (value, iface->_priv->default_gw);
       break;
+    case PROP_PEERDNS:
+      g_value_set_boolean (value, iface->_priv->peerdns);
+      break;
     case PROP_PERSIST:
       g_value_set_boolean (value, iface->_priv->persist);
       break;
@@ -293,10 +312,10 @@ gst_iface_isdn_get_property (GObject      *object,
     }
 }
 
-static const GdkPixbuf*
+static GdkPixbuf*
 gst_iface_isdn_get_pixbuf (GstIface *iface)
 {
-  return GST_IFACE_ISDN (iface)->_priv->pixbuf;
+  return gdk_pixbuf_new_from_file (PIXMAPS_DIR "/ppp.png", NULL);
 }
 
 static const gchar*
@@ -344,6 +363,7 @@ gst_iface_isdn_impl_get_xml (GstIface *iface, xmlNodePtr node)
 				 gst_iface_get_dev (iface));
 
       gst_xml_element_set_boolean (configuration, "set_default_gw", iface_isdn->_priv->default_gw);
+      gst_xml_element_set_boolean (configuration, "update_dns", iface_isdn->_priv->peerdns);
       gst_xml_element_set_boolean (configuration, "persist", iface_isdn->_priv->persist);
       gst_xml_element_set_boolean (configuration, "noauth",  iface_isdn->_priv->noauth);
     }
@@ -356,7 +376,7 @@ gst_iface_isdn_set_config_from_xml (GstIfaceIsdn *iface,
 				    xmlNodePtr    node)
 {
   gchar      *login, *password, *phone_number, *dial_prefix, *section;
-  gboolean    default_gw, persist;
+  gboolean    default_gw, peerdns, persist;
   xmlNodePtr  configuration;
 
   /* config the parent class data */
@@ -373,6 +393,7 @@ gst_iface_isdn_set_config_from_xml (GstIfaceIsdn *iface,
   section      = gst_xml_get_child_content (configuration, "section");
 
   default_gw = gst_xml_element_get_boolean (configuration, "set_default_gw");
+  peerdns    = gst_xml_element_get_boolean (configuration, "update_dns");
   persist    = gst_xml_element_get_boolean (configuration, "persist");
 
   g_object_set (G_OBJECT (iface),
@@ -381,6 +402,7 @@ gst_iface_isdn_set_config_from_xml (GstIfaceIsdn *iface,
                 "iface-phone-number", phone_number,
                 "iface-dial-prefix", dial_prefix,
                 "iface-default-gw", default_gw,
+                "iface-peerdns", peerdns,
                 "iface-persist", persist,
                 "iface-section", section,
 		/* FIXME: until we add some gui for noauth, it will
