@@ -29,8 +29,11 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
+#include <time.h>
 
-#include <gnome.h>
+#include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
 #include <glade/glade.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
@@ -209,7 +212,7 @@ gst_time_update_date (GstTimeTool *tool, gint add)
 		{ 0, 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 }
 	};
 	GtkWidget *calendar;
-	gint day, month, year;
+	guint day, month, year;
 	gint days_in_month;
 	gboolean leap_year;
 
@@ -379,7 +382,7 @@ timezone_button_clicked (GtkWidget *w, gpointer data)
 
 	gtk_window_set_transient_for (GTK_WINDOW (d), GTK_WINDOW (dialog));
 
-	while (gtk_dialog_run (GTK_DIALOG (d)) != GTK_RESPONSE_CLOSE);
+	while (gtk_dialog_run (GTK_DIALOG (d)) == GTK_RESPONSE_HELP);
 
 	tz_name     = e_tz_map_get_selected_tz_name (tzmap);
 	tz_location = e_tz_map_get_location_by_name (tzmap, tz_name);
@@ -408,7 +411,7 @@ server_button_clicked (GtkWidget *w, gpointer data)
 
 	gtk_window_set_transient_for (GTK_WINDOW (d), GTK_WINDOW (dialog));
 
-	while (gtk_dialog_run (GTK_DIALOG (d)) != GTK_RESPONSE_CLOSE);
+	while (gtk_dialog_run (GTK_DIALOG (d)) == GTK_RESPONSE_HELP);
 	gtk_widget_hide (d);
 }
 
@@ -708,7 +711,7 @@ void
 gst_time_set_full (GstTimeTool *time_tool, struct tm *tm)
 {
 	GtkWidget *calendar_widget;
-	gint day, month, year;
+	guint day, month, year;
 
 	calendar_widget = gst_dialog_get_widget (GST_TOOL (time_tool)->main_dialog, "calendar");
 	
